@@ -10,6 +10,7 @@ from typing import TYPE_CHECKING
 
 import pytest
 
+from virtualenv.cache import FileCache
 from virtualenv.discovery import cached_py_info
 from virtualenv.discovery.py_info import PythonInfo
 from virtualenv.info import fs_supports_symlink
@@ -25,8 +26,16 @@ if TYPE_CHECKING:
 
 @pytest.mark.slow
 @pytest.mark.parametrize("copies", [False, True] if fs_supports_symlink() else [True])
-def test_seed_link_via_app_data(tmp_path, coverage_env, current_fastest, copies):
-    current = PythonInfo.current_system()
+def test_seed_link_via_app_data(  # noqa: PLR0913, PLR0915
+    tmp_path,
+    coverage_env,
+    current_fastest,
+    copies,
+    for_py_version,
+    session_app_data,
+):
+    cache = FileCache(session_app_data.py_info, session_app_data.py_info_clear)
+    current = PythonInfo.current_system(session_app_data, cache)
     bundle_ver = BUNDLE_SUPPORT[current.version_release_str]
     create_cmd = [
         str(tmp_path / "en v"),  # space in the name to ensure generated scripts work when path has space
@@ -45,6 +54,8 @@ def test_seed_link_via_app_data(tmp_path, coverage_env, current_fastest, copies)
         current_fastest,
         "-vv",
     ]
+    if for_py_version == "3.8":
+        create_cmd += ["--wheel", bundle_ver["wheel"].split("-")[1]]
     if not copies:
         create_cmd.append("--symlink-app-data")
     result = cli_run(create_cmd)
@@ -109,7 +120,7 @@ def test_seed_link_via_app_data(tmp_path, coverage_env, current_fastest, copies)
 
     # Windows does not allow removing a executable while running it, so when uninstalling pip we need to do it via
     # python -m pip
-    remove_cmd = [str(result.creator.exe), "-m", "pip"] + remove_cmd[1:]
+    remove_cmd = [str(result.creator.exe), "-m", "pip", *remove_cmd[1:]]
     process = Popen([*remove_cmd, "pip", "wheel"])
     _, __ = process.communicate()
     assert not process.returncode
@@ -210,11 +221,18 @@ def test_populated_read_only_cache_and_copied_app_data(tmp_path, current_fastest
 @pytest.mark.slow
 @pytest.mark.parametrize("pkg", ["pip", "setuptools", "wheel"])
 @pytest.mark.usefixtures("session_app_data", "current_fastest", "coverage_env")
-def test_base_bootstrap_link_via_app_data_no(tmp_path, pkg):
-    create_cmd = [str(tmp_path), "--seeder", "app-data", f"--no-{pkg}", "--wheel", "bundle", "--setuptools", "bundle"]
+def test_base_bootstrap_link_via_app_data_no(tmp_path, pkg, for_py_version):
+    if for_py_version != "3.8" and pkg == "wheel":
+        msg = "wheel isn't installed on Python > 3.8"
+        raise pytest.skip(msg)
+    create_cmd = [str(tmp_path), "--seeder", "app-data", f"--no-{pkg}", "--setuptools", "bundle"]
+    if for_py_version == "3.8":
+        create_cmd += ["--wheel", "bundle"]
     result = cli_run(create_cmd)
     assert not (result.creator.purelib / pkg).exists()
     for key in {"pip", "setuptools", "wheel"} - {pkg}:
+        if for_py_version != "3.8" and key == "wheel":
+            continue
         assert (result.creator.purelib / key).exists()
 
 
@@ -230,7 +248,7 @@ def test_app_data_parallel_fail(tmp_path: Path, mocker: MockerFixture) -> None:
     exceptions = _run_parallel_threads(tmp_path)
     assert len(exceptions) == 2
     for exception in exceptions:
-        assert exception.startswith("failed to build image wheel because:\nTraceback")
+        assert exception.startswith("failed to build image pip because:\nTraceback")
         assert "RuntimeError" in exception, exception
 
 
@@ -239,7 +257,10 @@ def _run_parallel_threads(tmp_path):
 
     def _run(name):
         try:
-            cli_run(["--seeder", "app-data", str(tmp_path / name), "--no-pip", "--no-setuptools", "--wheel", "bundle"])
+            cmd = ["--seeder", "app-data", str(tmp_path / name), "--no-setuptools"]
+            if sys.version_info[:2] == (3, 8):
+                cmd.append("--no-wheel")
+            cli_run(cmd)
         except Exception as exception:  # noqa: BLE001
             as_str = str(exception)
             exceptions.append(as_str)
